@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2009 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2009-2010 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -51,22 +51,22 @@ static void     gcm_profile_finalize	(GObject     *object);
  **/
 struct _GcmProfilePrivate
 {
-	GcmProfileTypeEnum		 profile_type;
-	GcmColorspaceEnum		 colorspace;
-	guint				 size;
-	gboolean			 has_vcgt;
-	gchar				*description;
-	gchar				*filename;
-	GFileMonitor			*monitor;
-	gchar				*copyright;
-	gchar				*manufacturer;
-	gchar				*model;
-	gchar				*datetime;
-	GcmXyz				*white_point;
-	GcmXyz				*black_point;
-	GcmXyz				*luminance_red;
-	GcmXyz				*luminance_green;
-	GcmXyz				*luminance_blue;
+	GcmProfileKind		 kind;
+	GcmColorspace		 colorspace;
+	guint			 size;
+	gboolean		 has_vcgt;
+	gchar			*description;
+	gchar			*filename;
+	gchar			*copyright;
+	gchar			*manufacturer;
+	gchar			*model;
+	gchar			*datetime;
+	GcmXyz			*white;
+	GcmXyz			*black;
+	GcmXyz			*red;
+	GcmXyz			*green;
+	GcmXyz			*blue;
+	GFileMonitor		*monitor;
 };
 
 enum {
@@ -77,20 +77,299 @@ enum {
 	PROP_DATETIME,
 	PROP_DESCRIPTION,
 	PROP_FILENAME,
-	PROP_TYPE,
+	PROP_KIND,
 	PROP_COLORSPACE,
 	PROP_SIZE,
 	PROP_HAS_VCGT,
-	PROP_WHITE_POINT,
-	PROP_BLACK_POINT,
-	PROP_LUMINANCE_RED,
-	PROP_LUMINANCE_GREEN,
-	PROP_LUMINANCE_BLUE,
+	PROP_WHITE,
+	PROP_BLACK,
+	PROP_RED,
+	PROP_GREEN,
+	PROP_BLUE,
 	PROP_LAST
 };
 
 G_DEFINE_TYPE (GcmProfile, gcm_profile, G_TYPE_OBJECT)
 
+static void gcm_profile_file_monitor_changed_cb (GFileMonitor *monitor, GFile *file, GFile *other_file, GFileMonitorEvent event_type, GcmProfile *profile);
+
+/**
+ * gcm_profile_get_description:
+ **/
+const gchar *
+gcm_profile_get_description (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), NULL);
+	return profile->priv->description;
+}
+
+/**
+ * gcm_profile_set_description:
+ **/
+void
+gcm_profile_set_description (GcmProfile *profile, const gchar *description)
+{
+	GcmProfilePrivate *priv = profile->priv;
+	g_return_if_fail (GCM_IS_PROFILE (profile));
+
+	g_free (priv->description);
+	priv->description = g_strdup (description);
+
+	if (priv->description != NULL)
+		gcm_utils_ensure_printable (priv->description);
+
+	/* there's nothing sensible to display */
+	if (priv->description == NULL || priv->description[0] == '\0') {
+		g_free (priv->description);
+		if (priv->filename != NULL) {
+			priv->description = g_path_get_basename (priv->filename);
+		} else {
+			/* TRANSLATORS: this is where the ICC profile_lcms1 has no description */
+			priv->description = g_strdup (_("Missing description"));
+		}
+	}
+	g_object_notify (G_OBJECT (profile), "description");
+}
+
+
+/**
+ * gcm_profile_get_filename:
+ **/
+const gchar *
+gcm_profile_get_filename (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), NULL);
+	return profile->priv->filename;
+}
+
+/**
+ * gcm_profile_set_filename:
+ **/
+void
+gcm_profile_set_filename (GcmProfile *profile, const gchar *filename)
+{
+	GcmProfilePrivate *priv = profile->priv;
+	GFile *file;
+
+	g_return_if_fail (GCM_IS_PROFILE (profile));
+
+	g_free (priv->filename);
+	priv->filename = g_strdup (filename);
+
+	/* unref old instance */
+	if (priv->monitor != NULL) {
+		g_object_unref (priv->monitor);
+		priv->monitor = NULL;
+	}
+
+	/* setup watch on new profile */
+	if (priv->filename != NULL) {
+		file = g_file_new_for_path (priv->filename);
+		priv->monitor = g_file_monitor_file (file, G_FILE_MONITOR_NONE, NULL, NULL);
+		if (priv->monitor != NULL)
+			g_signal_connect (priv->monitor, "changed", G_CALLBACK(gcm_profile_file_monitor_changed_cb), profile);
+		g_object_unref (file);
+	}
+	g_object_notify (G_OBJECT (profile), "filename");
+}
+
+
+/**
+ * gcm_profile_get_copyright:
+ **/
+const gchar *
+gcm_profile_get_copyright (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), NULL);
+	return profile->priv->copyright;
+}
+
+/**
+ * gcm_profile_set_copyright:
+ **/
+void
+gcm_profile_set_copyright (GcmProfile *profile, const gchar *copyright)
+{
+	GcmProfilePrivate *priv = profile->priv;
+
+	g_return_if_fail (GCM_IS_PROFILE (profile));
+
+	g_free (priv->copyright);
+	priv->copyright = g_strdup (copyright);
+	if (priv->copyright != NULL)
+		gcm_utils_ensure_printable (priv->copyright);
+	g_object_notify (G_OBJECT (profile), "copyright");
+}
+
+
+/**
+ * gcm_profile_get_model:
+ **/
+const gchar *
+gcm_profile_get_model (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), NULL);
+	return profile->priv->model;
+}
+
+/**
+ * gcm_profile_set_model:
+ **/
+void
+gcm_profile_set_model (GcmProfile *profile, const gchar *model)
+{
+	GcmProfilePrivate *priv = profile->priv;
+
+	g_return_if_fail (GCM_IS_PROFILE (profile));
+
+	g_free (priv->model);
+	priv->model = g_strdup (model);
+	if (priv->model != NULL)
+		gcm_utils_ensure_printable (priv->model);
+	g_object_notify (G_OBJECT (profile), "model");
+}
+
+/**
+ * gcm_profile_get_manufacturer:
+ **/
+const gchar *
+gcm_profile_get_manufacturer (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), NULL);
+	return profile->priv->manufacturer;
+}
+
+/**
+ * gcm_profile_set_manufacturer:
+ **/
+void
+gcm_profile_set_manufacturer (GcmProfile *profile, const gchar *manufacturer)
+{
+	GcmProfilePrivate *priv = profile->priv;
+
+	g_return_if_fail (GCM_IS_PROFILE (profile));
+
+	g_free (priv->manufacturer);
+	priv->manufacturer = g_strdup (manufacturer);
+	if (priv->manufacturer != NULL)
+		gcm_utils_ensure_printable (priv->manufacturer);
+	g_object_notify (G_OBJECT (profile), "manufacturer");
+}
+
+
+/**
+ * gcm_profile_get_datetime:
+ **/
+const gchar *
+gcm_profile_get_datetime (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), NULL);
+	return profile->priv->datetime;
+}
+
+/**
+ * gcm_profile_set_datetime:
+ **/
+void
+gcm_profile_set_datetime (GcmProfile *profile, const gchar *datetime)
+{
+	GcmProfilePrivate *priv = profile->priv;
+
+	g_return_if_fail (GCM_IS_PROFILE (profile));
+
+	g_free (priv->datetime);
+	priv->datetime = g_strdup (datetime);
+	g_object_notify (G_OBJECT (profile), "datetime");
+}
+
+
+/**
+ * gcm_profile_get_size:
+ **/
+guint
+gcm_profile_get_size (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), 0);
+	return profile->priv->size;
+}
+
+/**
+ * gcm_profile_set_size:
+ **/
+void
+gcm_profile_set_size (GcmProfile *profile, guint size)
+{
+	g_return_if_fail (GCM_IS_PROFILE (profile));
+	profile->priv->size = size;
+	g_object_notify (G_OBJECT (profile), "size");
+}
+
+
+/**
+ * gcm_profile_get_kind:
+ **/
+GcmProfileKind
+gcm_profile_get_kind (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), GCM_PROFILE_KIND_UNKNOWN);
+	return profile->priv->kind;
+}
+
+/**
+ * gcm_profile_set_kind:
+ **/
+void
+gcm_profile_set_kind (GcmProfile *profile, GcmProfileKind kind)
+{
+	g_return_if_fail (GCM_IS_PROFILE (profile));
+	profile->priv->kind = kind;
+	g_object_notify (G_OBJECT (profile), "kind");
+}
+
+
+/**
+ * gcm_profile_get_colorspace:
+ **/
+GcmColorspace
+gcm_profile_get_colorspace (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), GCM_COLORSPACE_UNKNOWN);
+	return profile->priv->colorspace;
+}
+
+/**
+ * gcm_profile_set_colorspace:
+ **/
+void
+gcm_profile_set_colorspace (GcmProfile *profile, GcmColorspace colorspace)
+{
+	g_return_if_fail (GCM_IS_PROFILE (profile));
+	profile->priv->colorspace = colorspace;
+	g_object_notify (G_OBJECT (profile), "colorspace");
+}
+
+
+/**
+ * gcm_profile_get_has_vcgt:
+ **/
+gboolean
+gcm_profile_get_has_vcgt (GcmProfile *profile)
+{
+	g_return_val_if_fail (GCM_IS_PROFILE (profile), FALSE);
+	return profile->priv->has_vcgt;
+}
+
+/**
+ * gcm_profile_set_has_vcgt:
+ **/
+void
+gcm_profile_set_has_vcgt (GcmProfile *profile, gboolean has_vcgt)
+{
+	g_return_if_fail (GCM_IS_PROFILE (profile));
+	profile->priv->has_vcgt = has_vcgt;
+	g_object_notify (G_OBJECT (profile), "has_vcgt");
+}
+
 /**
  * gcm_profile_parse_data:
  **/
@@ -124,7 +403,7 @@ gcm_profile_parse (GcmProfile *profile, GFile *file, GError **error)
 {
 	gchar *data = NULL;
 	gboolean ret;
-	guint length;
+	gsize length;
 	gchar *filename = NULL;
 	GError *error_local = NULL;
 
@@ -132,7 +411,7 @@ gcm_profile_parse (GcmProfile *profile, GFile *file, GError **error)
 	g_return_val_if_fail (file != NULL, FALSE);
 
 	/* load files */
-	ret = g_file_load_contents (file, NULL, &data, (gsize *) &length, NULL, &error_local);
+	ret = g_file_load_contents (file, NULL, &data, &length, NULL, &error_local);
 	if (!ret) {
 		g_set_error (error, 1, 0, "failed to load profile: %s", error_local->message);
 		g_error_free (error_local);
@@ -146,9 +425,7 @@ gcm_profile_parse (GcmProfile *profile, GFile *file, GError **error)
 
 	/* save */
 	filename = g_file_get_path (file);
-	g_object_set (profile,
-		      "filename", filename,
-		      NULL);
+	gcm_profile_set_filename (profile, filename);
 out:
 	g_free (filename);
 	g_free (data);
@@ -239,9 +516,7 @@ gcm_profile_file_monitor_changed_cb (GFileMonitor *monitor, GFile *file, GFile *
 
 	/* just rescan everything */
 	egg_debug ("%s deleted, clearing filename", priv->filename);
-	g_object_set (profile,
-		      "filename", NULL,
-		      NULL);
+	gcm_profile_set_filename (profile, NULL);
 out:
 	return;
 }
@@ -274,8 +549,8 @@ gcm_profile_get_property (GObject *object, guint prop_id, GValue *value, GParamS
 	case PROP_FILENAME:
 		g_value_set_string (value, priv->filename);
 		break;
-	case PROP_TYPE:
-		g_value_set_uint (value, priv->profile_type);
+	case PROP_KIND:
+		g_value_set_uint (value, priv->kind);
 		break;
 	case PROP_COLORSPACE:
 		g_value_set_uint (value, priv->colorspace);
@@ -286,20 +561,20 @@ gcm_profile_get_property (GObject *object, guint prop_id, GValue *value, GParamS
 	case PROP_HAS_VCGT:
 		g_value_set_boolean (value, priv->has_vcgt);
 		break;
-	case PROP_WHITE_POINT:
-		g_value_set_object (value, priv->white_point);
+	case PROP_WHITE:
+		g_value_set_object (value, priv->white);
 		break;
-	case PROP_BLACK_POINT:
-		g_value_set_object (value, priv->black_point);
+	case PROP_BLACK:
+		g_value_set_object (value, priv->black);
 		break;
-	case PROP_LUMINANCE_RED:
-		g_value_set_object (value, priv->luminance_red);
+	case PROP_RED:
+		g_value_set_object (value, priv->red);
 		break;
-	case PROP_LUMINANCE_GREEN:
-		g_value_set_object (value, priv->luminance_green);
+	case PROP_GREEN:
+		g_value_set_object (value, priv->green);
 		break;
-	case PROP_LUMINANCE_BLUE:
-		g_value_set_object (value, priv->luminance_blue);
+	case PROP_BLUE:
+		g_value_set_object (value, priv->blue);
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -315,93 +590,52 @@ gcm_profile_set_property (GObject *object, guint prop_id, const GValue *value, G
 {
 	GcmProfile *profile = GCM_PROFILE (object);
 	GcmProfilePrivate *priv = profile->priv;
-	GFile *file;
 
 	switch (prop_id) {
 	case PROP_COPYRIGHT:
-		g_free (priv->copyright);
-		priv->copyright = g_strdup (g_value_get_string (value));
-		if (priv->copyright != NULL)
-			gcm_utils_ensure_printable (priv->copyright);
+		gcm_profile_set_copyright (profile, g_value_get_string (value));
 		break;
 	case PROP_MANUFACTURER:
-		g_free (priv->manufacturer);
-		priv->manufacturer = g_strdup (g_value_get_string (value));
-		if (priv->manufacturer != NULL)
-			gcm_utils_ensure_printable (priv->manufacturer);
+		gcm_profile_set_manufacturer (profile, g_value_get_string (value));
 		break;
 	case PROP_MODEL:
-		g_free (priv->model);
-		priv->model = g_strdup (g_value_get_string (value));
-		if (priv->model != NULL)
-			gcm_utils_ensure_printable (priv->model);
+		gcm_profile_set_model (profile, g_value_get_string (value));
 		break;
 	case PROP_DATETIME:
-		g_free (priv->datetime);
-		priv->datetime = g_strdup (g_value_get_string (value));
+		gcm_profile_set_datetime (profile, g_value_get_string (value));
 		break;
 	case PROP_DESCRIPTION:
-		g_free (priv->description);
-		priv->description = g_strdup (g_value_get_string (value));
-		if (priv->description != NULL)
-			gcm_utils_ensure_printable (priv->description);
-
-		/* there's nothing sensible to display */
-		if (priv->description == NULL || priv->description[0] == '\0') {
-			g_free (priv->description);
-			if (priv->filename != NULL) {
-				priv->description = g_path_get_basename (priv->filename);
-			} else {
-				/* TRANSLATORS: this is where the ICC profile_lcms1 has no description */
-				priv->description = g_strdup (_("Missing description"));
-			}
-		}
+		gcm_profile_set_description (profile, g_value_get_string (value));
 		break;
 	case PROP_FILENAME:
-		g_free (priv->filename);
-		priv->filename = g_strdup (g_value_get_string (value));
-
-		/* unref old instance */
-		if (priv->monitor != NULL) {
-			g_object_unref (priv->monitor);
-			priv->monitor = NULL;
-		}
-
-		/* setup watch on new profile */
-		if (priv->filename != NULL) {
-			file = g_file_new_for_path (priv->filename);
-			priv->monitor = g_file_monitor_file (file, G_FILE_MONITOR_NONE, NULL, NULL);
-			if (priv->monitor != NULL)
-				g_signal_connect (priv->monitor, "changed", G_CALLBACK(gcm_profile_file_monitor_changed_cb), profile);
-			g_object_unref (file);
-		}
+		gcm_profile_set_filename (profile, g_value_get_string (value));
 		break;
-	case PROP_TYPE:
-		priv->profile_type = g_value_get_uint (value);
+	case PROP_KIND:
+		gcm_profile_set_kind (profile, g_value_get_uint (value));
 		break;
 	case PROP_COLORSPACE:
-		priv->colorspace = g_value_get_uint (value);
+		gcm_profile_set_colorspace (profile, g_value_get_uint (value));
 		break;
 	case PROP_SIZE:
-		priv->size = g_value_get_uint (value);
+		gcm_profile_set_size (profile, g_value_get_uint (value));
 		break;
 	case PROP_HAS_VCGT:
-		priv->has_vcgt = g_value_get_boolean (value);
+		gcm_profile_set_has_vcgt (profile, g_value_get_boolean (value));
 		break;
-	case PROP_WHITE_POINT:
-		priv->white_point = g_value_dup_object (value);
+	case PROP_WHITE:
+		priv->white = g_value_dup_object (value);
 		break;
-	case PROP_BLACK_POINT:
-		priv->black_point = g_value_dup_object (value);
+	case PROP_BLACK:
+		priv->black = g_value_dup_object (value);
 		break;
-	case PROP_LUMINANCE_RED:
-		priv->luminance_red = g_value_dup_object (value);
+	case PROP_RED:
+		priv->red = g_value_dup_object (value);
 		break;
-	case PROP_LUMINANCE_GREEN:
-		priv->luminance_green = g_value_dup_object (value);
+	case PROP_GREEN:
+		priv->green = g_value_dup_object (value);
 		break;
-	case PROP_LUMINANCE_BLUE:
-		priv->luminance_blue = g_value_dup_object (value);
+	case PROP_BLUE:
+		priv->blue = g_value_dup_object (value);
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -470,12 +704,12 @@ gcm_profile_class_init (GcmProfileClass *klass)
 	g_object_class_install_property (object_class, PROP_FILENAME, pspec);
 
 	/**
-	 * GcmProfile:type:
+	 * GcmProfile:kind:
 	 */
-	pspec = g_param_spec_uint ("type", NULL, NULL,
+	pspec = g_param_spec_uint ("kind", NULL, NULL,
 				   0, G_MAXUINT, 0,
 				   G_PARAM_READWRITE);
-	g_object_class_install_property (object_class, PROP_TYPE, pspec);
+	g_object_class_install_property (object_class, PROP_KIND, pspec);
 
 	/**
 	 * GcmProfile:colorspace:
@@ -502,44 +736,44 @@ gcm_profile_class_init (GcmProfileClass *klass)
 	g_object_class_install_property (object_class, PROP_HAS_VCGT, pspec);
 
 	/**
-	 * GcmProfile:white-point:
+	 * GcmProfile:white:
 	 */
-	pspec = g_param_spec_object ("white-point", NULL, NULL,
+	pspec = g_param_spec_object ("white", NULL, NULL,
 				     GCM_TYPE_XYZ,
 				     G_PARAM_READWRITE);
-	g_object_class_install_property (object_class, PROP_WHITE_POINT, pspec);
+	g_object_class_install_property (object_class, PROP_WHITE, pspec);
 
 	/**
-	 * GcmProfile:black-point:
+	 * GcmProfile:black:
 	 */
-	pspec = g_param_spec_object ("black-point", NULL, NULL,
+	pspec = g_param_spec_object ("black", NULL, NULL,
 				     GCM_TYPE_XYZ,
 				     G_PARAM_READWRITE);
-	g_object_class_install_property (object_class, PROP_BLACK_POINT, pspec);
+	g_object_class_install_property (object_class, PROP_BLACK, pspec);
 
 	/**
-	 * GcmProfile:luminance-red:
+	 * GcmProfile:red:
 	 */
-	pspec = g_param_spec_object ("luminance-red", NULL, NULL,
+	pspec = g_param_spec_object ("red", NULL, NULL,
 				     GCM_TYPE_XYZ,
 				     G_PARAM_READWRITE);
-	g_object_class_install_property (object_class, PROP_LUMINANCE_RED, pspec);
+	g_object_class_install_property (object_class, PROP_RED, pspec);
 
 	/**
-	 * GcmProfile:luminance-green:
+	 * GcmProfile:green:
 	 */
-	pspec = g_param_spec_object ("luminance-green", NULL, NULL,
+	pspec = g_param_spec_object ("green", NULL, NULL,
 				     GCM_TYPE_XYZ,
 				     G_PARAM_READWRITE);
-	g_object_class_install_property (object_class, PROP_LUMINANCE_GREEN, pspec);
+	g_object_class_install_property (object_class, PROP_GREEN, pspec);
 
 	/**
-	 * GcmProfile:luminance-blue:
+	 * GcmProfile:blue:
 	 */
-	pspec = g_param_spec_object ("luminance-blue", NULL, NULL,
+	pspec = g_param_spec_object ("blue", NULL, NULL,
 				     GCM_TYPE_XYZ,
 				     G_PARAM_READWRITE);
-	g_object_class_install_property (object_class, PROP_LUMINANCE_BLUE, pspec);
+	g_object_class_install_property (object_class, PROP_BLUE, pspec);
 
 	g_type_class_add_private (klass, sizeof (GcmProfilePrivate));
 }
@@ -552,13 +786,13 @@ gcm_profile_init (GcmProfile *profile)
 {
 	profile->priv = GCM_PROFILE_GET_PRIVATE (profile);
 	profile->priv->monitor = NULL;
-	profile->priv->profile_type = GCM_PROFILE_TYPE_ENUM_UNKNOWN;
-	profile->priv->colorspace = GCM_COLORSPACE_ENUM_UNKNOWN;
-	profile->priv->white_point = gcm_xyz_new ();
-	profile->priv->black_point = gcm_xyz_new ();
-	profile->priv->luminance_red = gcm_xyz_new ();
-	profile->priv->luminance_green = gcm_xyz_new ();
-	profile->priv->luminance_blue = gcm_xyz_new ();
+	profile->priv->kind = GCM_PROFILE_KIND_UNKNOWN;
+	profile->priv->colorspace = GCM_COLORSPACE_UNKNOWN;
+	profile->priv->white = gcm_xyz_new ();
+	profile->priv->black = gcm_xyz_new ();
+	profile->priv->red = gcm_xyz_new ();
+	profile->priv->green = gcm_xyz_new ();
+	profile->priv->blue = gcm_xyz_new ();
 }
 
 /**
@@ -576,11 +810,11 @@ gcm_profile_finalize (GObject *object)
 	g_free (priv->manufacturer);
 	g_free (priv->model);
 	g_free (priv->datetime);
-	g_object_unref (priv->white_point);
-	g_object_unref (priv->black_point);
-	g_object_unref (priv->luminance_red);
-	g_object_unref (priv->luminance_green);
-	g_object_unref (priv->luminance_blue);
+	g_object_unref (priv->white);
+	g_object_unref (priv->black);
+	g_object_unref (priv->red);
+	g_object_unref (priv->green);
+	g_object_unref (priv->blue);
 	if (priv->monitor != NULL)
 		g_object_unref (priv->monitor);
 
@@ -609,9 +843,7 @@ GcmProfile *
 gcm_profile_default_new (void)
 {
 	GcmProfile *profile = NULL;
-#ifdef GCM_HAVE_LCMS
 	profile = GCM_PROFILE (gcm_profile_lcms1_new ());
-#endif
 	return profile;
 }
 
@@ -628,26 +860,24 @@ typedef struct {
 	const gchar *model;
 	const gchar *datetime;
 	const gchar *description;
-	GcmProfileTypeEnum type;
-	GcmColorspaceEnum colorspace;
+	GcmProfileKind kind;
+	GcmColorspace colorspace;
 	gfloat luminance;
 } GcmProfileTestData;
 
 void
 gcm_profile_test_parse_file (EggTest *test, const guint8 *datafile, GcmProfileTestData *test_data)
 {
-	gchar *filename;
-	gchar *filename_tmp;
-	gchar *copyright;
-	gchar *manufacturer;
-	gchar *model;
-	gchar *datetime;
-	gchar *description;
-	gchar *ascii_string;
-	gchar *pnp_id;
-	gchar *data;
+	gchar *filename = NULL;
+	const gchar *copyright;
+	const gchar *manufacturer;
+	const gchar *model;
+	const gchar *datetime;
+	const gchar *description;
+	const gchar *ascii_string;
+	const gchar *pnp_id;
 	guint width;
-	guint type;
+	guint kind;
 	guint colorspace;
 	gfloat gamma;
 	gboolean ret;
@@ -677,20 +907,9 @@ gcm_profile_test_parse_file (EggTest *test, const guint8 *datafile, GcmProfileTe
 		egg_test_failed (test, "failed to parse: %s", error->message);
 	g_object_unref (file);
 
-	/* get some properties */
-	g_object_get (profile_lcms1,
-		      "copyright", &copyright,
-		      "manufacturer", &manufacturer,
-		      "model", &model,
-		      "datetime", &datetime,
-		      "description", &description,
-		      "filename", &filename_tmp,
-		      "type", &type,
-		      "colorspace", &colorspace,
-		      NULL);
-
 	/************************************************************/
 	egg_test_title (test, "check copyright for %s", datafile);
+	copyright = gcm_profile_get_copyright (profile_lcms1);
 	if (g_strcmp0 (copyright, test_data->copyright) == 0)
 		egg_test_success (test, NULL);
 	else
@@ -698,6 +917,7 @@ gcm_profile_test_parse_file (EggTest *test, const guint8 *datafile, GcmProfileTe
 
 	/************************************************************/
 	egg_test_title (test, "check manufacturer for %s", datafile);
+	manufacturer = gcm_profile_get_manufacturer (profile_lcms1);
 	if (g_strcmp0 (manufacturer, test_data->manufacturer) == 0)
 		egg_test_success (test, NULL);
 	else
@@ -705,6 +925,7 @@ gcm_profile_test_parse_file (EggTest *test, const guint8 *datafile, GcmProfileTe
 
 	/************************************************************/
 	egg_test_title (test, "check model for %s", datafile);
+	model = gcm_profile_get_model (profile_lcms1);
 	if (g_strcmp0 (model, test_data->model) == 0)
 		egg_test_success (test, NULL);
 	else
@@ -712,6 +933,7 @@ gcm_profile_test_parse_file (EggTest *test, const guint8 *datafile, GcmProfileTe
 
 	/************************************************************/
 	egg_test_title (test, "check datetime for %s", datafile);
+	datetime = gcm_profile_get_datetime (profile_lcms1);
 	if (g_strcmp0 (datetime, test_data->datetime) == 0)
 		egg_test_success (test, NULL);
 	else
@@ -719,20 +941,23 @@ gcm_profile_test_parse_file (EggTest *test, const guint8 *datafile, GcmProfileTe
 
 	/************************************************************/
 	egg_test_title (test, "check description for %s", datafile);
+	description = gcm_profile_get_description (profile_lcms1);
 	if (g_strcmp0 (description, test_data->description) == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "invalid value: %s, expecting: %s", description, test_data->description);
 
 	/************************************************************/
-	egg_test_title (test, "check type for %s", datafile);
-	if (type == test_data->type)
+	egg_test_title (test, "check kind for %s", datafile);
+	kind = gcm_profile_get_kind (profile_lcms1);
+	if (kind == test_data->kind)
 		egg_test_success (test, NULL);
 	else
-		egg_test_failed (test, "invalid value: %i, expecting: %i", type, test_data->type);
+		egg_test_failed (test, "invalid value: %i, expecting: %i", kind, test_data->kind);
 
 	/************************************************************/
 	egg_test_title (test, "check colorspace for %s", datafile);
+	colorspace = gcm_profile_get_colorspace (profile_lcms1);
 	if (colorspace == test_data->colorspace)
 		egg_test_success (test, NULL);
 	else
@@ -741,7 +966,7 @@ gcm_profile_test_parse_file (EggTest *test, const guint8 *datafile, GcmProfileTe
 	/************************************************************/
 	egg_test_title (test, "check luminance red %s", datafile);
 	g_object_get (profile_lcms1,
-		      "luminance-red", &xyz,
+		      "red", &xyz,
 		      NULL);
 	luminance = gcm_xyz_get_x (xyz);
 	if (fabs (luminance - test_data->luminance) < 0.001)
@@ -751,14 +976,7 @@ gcm_profile_test_parse_file (EggTest *test, const guint8 *datafile, GcmProfileTe
 
 	g_object_unref (xyz);
 	g_object_unref (profile_lcms1);
-	g_free (copyright);
-	g_free (manufacturer);
-	g_free (model);
-	g_free (datetime);
-	g_free (description);
-	g_free (data);
 	g_free (filename);
-	g_free (filename_tmp);
 }
 
 void
@@ -774,8 +992,8 @@ gcm_profile_test (EggTest *test)
 	test_data.manufacturer = "IEC http://www.iec.ch";
 	test_data.model = "IEC 61966-2.1 Default RGB colour space - sRGB";
 	test_data.description = "Blueish Test";
-	test_data.type = GCM_PROFILE_TYPE_ENUM_DISPLAY_DEVICE;
-	test_data.colorspace = GCM_COLORSPACE_ENUM_RGB;
+	test_data.kind = GCM_PROFILE_KIND_DISPLAY_DEVICE;
+	test_data.colorspace = GCM_COLORSPACE_RGB;
 	test_data.luminance = 0.648454;
 	test_data.datetime = "February  9 1998, 06:49:00 AM";
 	gcm_profile_test_parse_file (test, "bluish.icc", &test_data);
@@ -785,8 +1003,8 @@ gcm_profile_test (EggTest *test)
 	test_data.manufacturer = "IEC http://www.iec.ch";
 	test_data.model = "IEC 61966-2.1 Default RGB colour space - sRGB";
 	test_data.description = "ADOBEGAMMA-Test";
-	test_data.type = GCM_PROFILE_TYPE_ENUM_DISPLAY_DEVICE;
-	test_data.colorspace = GCM_COLORSPACE_ENUM_RGB;
+	test_data.kind = GCM_PROFILE_KIND_DISPLAY_DEVICE;
+	test_data.colorspace = GCM_COLORSPACE_RGB;
 	test_data.luminance = 0.648446;
 	test_data.datetime = "August 16 2005, 09:49:54 PM";
 	gcm_profile_test_parse_file (test, "AdobeGammaTest.icm", &test_data);
